# fitbit-web-api

Fitbit provides a Web API for accessing data from Fitbit activity trackers, Aria scale, and manually entered logs. Anyone can develop an application to access and modify a Fitbit user's data on their behalf, so long as it complies with Fitbit Platform Terms of Service. These Swagger UI docs do not currently support making Fitbit API requests directly. In order to make a request, construct a request for the appropriate endpoint using this documentation, and then add an Authorization header to each request with an access token obtained using the steps outlined here: https://dev.fitbit.com/build/reference/web-api/developer-guide/authorization/.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
  For more information, please visit [https://dev.fitbit.com/build/reference/web-api/help/](https://dev.fitbit.com/build/reference/web-api/help/)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```

(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:

```python
import fitbit_web_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```

(or `sudo python setup.py install` to install the package for all users)

Then import the package:

```python
import fitbit_web_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import fitbit_web_api
from fitbit_web_api.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth2
configuration = fitbit_web_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = fitbit_web_api.ActiveZoneMinutesIntradayTimeSeriesApi(fitbit_web_api.ApiClient(configuration))
_date = '2013-10-20' # date | The date in the format yyyy-MM-dd or today
detail_level = 'detail_level_example' # str | The detail for which data will be returned. **Supported:** 1min | 5min | 15min

try:
    # Get AZM Intraday by Date
    api_instance.get_azmby_date_intraday(_date, detail_level)
except ApiException as e:
    print("Exception when calling ActiveZoneMinutesIntradayTimeSeriesApi->get_azmby_date_intraday: %s\n" % e)

# Configure OAuth2 access token for authorization: oauth2
configuration = fitbit_web_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = fitbit_web_api.ActiveZoneMinutesIntradayTimeSeriesApi(fitbit_web_api.ApiClient(configuration))
_date = '2013-10-20' # date | The date in the format yyyy-MM-dd or today
detail_level = 'detail_level_example' # str | The detail for which data will be returned. **Supported:** 1min | 5min | 15min
start_time = 'start_time_example' # str | The start of the period in the format HH:mm.
end_time = 'end_time_example' # str | The end of the period in the format HH:mm.

try:
    # Get AZM Intraday by Date
    api_instance.get_azmby_date_time_series_intraday(_date, detail_level, start_time, end_time)
except ApiException as e:
    print("Exception when calling ActiveZoneMinutesIntradayTimeSeriesApi->get_azmby_date_time_series_intraday: %s\n" % e)

# Configure OAuth2 access token for authorization: oauth2
configuration = fitbit_web_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = fitbit_web_api.ActiveZoneMinutesIntradayTimeSeriesApi(fitbit_web_api.ApiClient(configuration))
start_date = '2013-10-20' # date | The date in the format yyyy-MM-dd or today
end_date = '2013-10-20' # date | The date in the format yyyy-MM-dd or today
detail_level = 'detail_level_example' # str | The detail for which data will be returned. **Support:** 1min | 5min | 15min

try:
    # Get AZM Intraday by Interval
    api_instance.get_azmby_interval_intraday(start_date, end_date, detail_level)
except ApiException as e:
    print("Exception when calling ActiveZoneMinutesIntradayTimeSeriesApi->get_azmby_interval_intraday: %s\n" % e)

# Configure OAuth2 access token for authorization: oauth2
configuration = fitbit_web_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = fitbit_web_api.ActiveZoneMinutesIntradayTimeSeriesApi(fitbit_web_api.ApiClient(configuration))
start_date = '2013-10-20' # date | The date in the format yyyy-MM-dd or today
end_date = '2013-10-20' # date | The date in the format yyyy-MM-dd or today
detail_level = 'detail_level_example' # str | The detail for which data will be returned. **Support:** 1min | 5min | 15min
start_time = 'start_time_example' # str | The start of the period in the format HH:mm.
end_time = 'end_time_example' # str | The end of the period in the format HH:mm.

try:
    # Get AZM Intraday by Interval
    api_instance.get_azmby_interval_time_series_intraday(start_date, end_date, detail_level, start_time, end_time)
except ApiException as e:
    print("Exception when calling ActiveZoneMinutesIntradayTimeSeriesApi->get_azmby_interval_time_series_intraday: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.fitbit.com/*

| Class                                    | Method                                                                                                                                                             | HTTP request                                                                                                         | Description                                             |
| ---------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------ | -------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------- |
| _ActiveZoneMinutesIntradayTimeSeriesApi_ | [**get_azmby_date_intraday**](docs/ActiveZoneMinutesIntradayTimeSeriesApi.md#get_azmby_date_intraday)                                                              | **GET** /1/user/-/activities/active-zone-minutes/date/{date}/1d/{detail-level}.json                                  | Get AZM Intraday by Date                                |
| _ActiveZoneMinutesIntradayTimeSeriesApi_ | [**get_azmby_date_time_series_intraday**](docs/ActiveZoneMinutesIntradayTimeSeriesApi.md#get_azmby_date_time_series_intraday)                                      | **GET** /1/user/-/activities/active-zone-minutes/date/{date}/1d/{detail-level}/time/{start-time}/{end-time}.json     | Get AZM Intraday by Date                                |
| _ActiveZoneMinutesIntradayTimeSeriesApi_ | [**get_azmby_interval_intraday**](docs/ActiveZoneMinutesIntradayTimeSeriesApi.md#get_azmby_interval_intraday)                                                      | **GET** /1/user/-/activities/active-zone-minutes/date/{start-date}/{end-date}/{detail-level}.json                    | Get AZM Intraday by Interval                            |
| _ActiveZoneMinutesIntradayTimeSeriesApi_ | [**get_azmby_interval_time_series_intraday**](docs/ActiveZoneMinutesIntradayTimeSeriesApi.md#get_azmby_interval_time_series_intraday)                              | **GET** /1/user/-/activities/active-zone-minutes/date/{start-date}/{end-date}/time/{start-time}/{end-time}.json      | Get AZM Intraday by Interval                            |
| _ActiveZoneMinutesTimeSeriesApi_         | [**get_azm_time_series_by_date**](docs/ActiveZoneMinutesTimeSeriesApi.md#get_azm_time_series_by_date)                                                              | **GET** /1/user/-/activities/active-zone-minutes/date/{date}/{period}.json                                           | Get AZM Time Series by Date                             |
| _ActiveZoneMinutesTimeSeriesApi_         | [**get_azm_time_series_by_interval**](docs/ActiveZoneMinutesTimeSeriesApi.md#get_azm_time_series_by_interval)                                                      | **GET** /1/user/-/activities/active-zone-minutes/date/{start-date}/{end-date}.json                                   | Get AZM Time Series by Interval                         |
| _ActivityApi_                            | [**add_activities_log**](docs/ActivityApi.md#add_activities_log)                                                                                                   | **POST** /1/user/-/activities.json                                                                                   | Log Activity                                            |
| _ActivityApi_                            | [**add_favorite_activities**](docs/ActivityApi.md#add_favorite_activities)                                                                                         | **POST** /1/user/-/activities/favorite/{activity-id}.json                                                            | Add Favorite Activity                                   |
| _ActivityApi_                            | [**add_update_activities_goals**](docs/ActivityApi.md#add_update_activities_goals)                                                                                 | **POST** /1/user/-/activities/goals/{period}.json                                                                    | Update Activity Goals                                   |
| _ActivityApi_                            | [**delete_activities_log**](docs/ActivityApi.md#delete_activities_log)                                                                                             | **DELETE** /1/user/-/activities/{activity-log-id}.json                                                               | Delete Activity Log                                     |
| _ActivityApi_                            | [**delete_favorite_activities**](docs/ActivityApi.md#delete_favorite_activities)                                                                                   | **DELETE** /1/user/-/activities/favorite/{activity-id}.json                                                          | Delete Favorite Activity                                |
| _ActivityApi_                            | [**get_activities_by_date**](docs/ActivityApi.md#get_activities_by_date)                                                                                           | **GET** /1/user/-/activities/date/{date}.json                                                                        | Get Activity Summary by Date                            |
| _ActivityApi_                            | [**get_activities_goals**](docs/ActivityApi.md#get_activities_goals)                                                                                               | **GET** /1/user/-/activities/goals/{period}.json                                                                     | Get Activity Goals                                      |
| _ActivityApi_                            | [**get_activities_log**](docs/ActivityApi.md#get_activities_log)                                                                                                   | **GET** /1/user/-/activities.json                                                                                    | Get Lifetime Stats                                      |
| _ActivityApi_                            | [**get_activities_log_list**](docs/ActivityApi.md#get_activities_log_list)                                                                                         | **GET** /1/user/-/activities/list.json                                                                               | Get Activity Log List                                   |
| _ActivityApi_                            | [**get_activities_tcx**](docs/ActivityApi.md#get_activities_tcx)                                                                                                   | **GET** /1/user/-/activities/{log-id}.tcx                                                                            | Get Activity TCX                                        |
| _ActivityApi_                            | [**get_activities_type_detail**](docs/ActivityApi.md#get_activities_type_detail)                                                                                   | **GET** /1/activities/{activity-id}.json                                                                             | Get Activity Type                                       |
| _ActivityApi_                            | [**get_activities_types**](docs/ActivityApi.md#get_activities_types)                                                                                               | **GET** /1/activities.json                                                                                           | Browse Activity Types                                   |
| _ActivityApi_                            | [**get_favorite_activities**](docs/ActivityApi.md#get_favorite_activities)                                                                                         | **GET** /1/user/-/activities/favorite.json                                                                           | Get Favorite Activities                                 |
| _ActivityApi_                            | [**get_frequent_activities**](docs/ActivityApi.md#get_frequent_activities)                                                                                         | **GET** /1/user/-/activities/frequent.json                                                                           | Get Frequent Activities                                 |
| _ActivityApi_                            | [**get_recent_activities**](docs/ActivityApi.md#get_recent_activities)                                                                                             | **GET** /1/user/-/activities/recent.json                                                                             | Get Recent Activity Types                               |
| _ActivityIntradayTimeSeriesApi_          | [**get_activities_resource_by_date_intraday**](docs/ActivityIntradayTimeSeriesApi.md#get_activities_resource_by_date_intraday)                                     | **GET** /1/user/-/activities/{resource-path}/date/{date}/1d/{detail-level}.json                                      | Get Intraday Time Series                                |
| _ActivityIntradayTimeSeriesApi_          | [**get_activities_resource_by_date_range_intraday**](docs/ActivityIntradayTimeSeriesApi.md#get_activities_resource_by_date_range_intraday)                         | **GET** /1/user/-/activities/{resource-path}/date/{base-date}/{end-date}/{detail-level}.json                         | Get Activity Intraday Time Series                       |
| _ActivityIntradayTimeSeriesApi_          | [**get_activities_resource_by_date_range_time_series_intraday**](docs/ActivityIntradayTimeSeriesApi.md#get_activities_resource_by_date_range_time_series_intraday) | **GET** /1/user/-/activities/{resource-path}/date/{date}/{end-date}/{detail-level}/time/{start-time}/{end-time}.json | Get Activity Intraday Time Series                       |
| _ActivityIntradayTimeSeriesApi_          | [**get_activities_resource_by_date_time_series_intraday**](docs/ActivityIntradayTimeSeriesApi.md#get_activities_resource_by_date_time_series_intraday)             | **GET** /1/user/-/activities/{resource-path}/date/{date}/1d/{detail-level}/time/{start-time}/{end-time}.json         | Get Intraday Time Series                                |
| _ActivityTimeSeriesApi_                  | [**get_activities_resource_by_date_period**](docs/ActivityTimeSeriesApi.md#get_activities_resource_by_date_period)                                                 | **GET** /1/user/-/activities/{resource-path}/date/{date}/{period}.json                                               | Get Activity Time Series                                |
| _ActivityTimeSeriesApi_                  | [**get_activities_resource_by_date_range**](docs/ActivityTimeSeriesApi.md#get_activities_resource_by_date_range)                                                   | **GET** /1/user/-/activities/{resource-path}/date/{base-date}/{end-date}.json                                        | Get Activity Resource by Date Range                     |
| _ActivityTimeSeriesApi_                  | [**get_activities_tracker_resource_by_date_period**](docs/ActivityTimeSeriesApi.md#get_activities_tracker_resource_by_date_period)                                 | **GET** /1/user/-/activities/tracker/{resource-path}/date/{date}/{period}.json                                       | Get Activity Time Series                                |
| _ActivityTimeSeriesApi_                  | [**get_activities_tracker_resource_by_date_range**](docs/ActivityTimeSeriesApi.md#get_activities_tracker_resource_by_date_range)                                   | **GET** /1/user/-/activities/tracker/{resource-path}/date/{base-date}/{end-date}.json                                | Get Activity Tracker Resource by Date Range Time Series |
| _AuthorizationApi_                       | [**introspect**](docs/AuthorizationApi.md#introspect)                                                                                                              | **POST** /1.1/oauth2/introspect                                                                                      | Retrieve the active state of an OAuth 2.0 token         |
| _AuthorizationApi_                       | [**oauth_token**](docs/AuthorizationApi.md#oauth_token)                                                                                                            | **POST** /oauth2/token                                                                                               | Get OAuth 2 access token                                |
| _AuthorizationApi_                       | [**revoke**](docs/AuthorizationApi.md#revoke)                                                                                                                      | **POST** /oauth2/revoke                                                                                              | Revokes consent of the access token or refresh token    |
| _BodyApi_                                | [**add_body_fat_log**](docs/BodyApi.md#add_body_fat_log)                                                                                                           | **POST** /1/user/-/body/log/fat.json                                                                                 | Log Body Fat                                            |
| _BodyApi_                                | [**add_weight_log**](docs/BodyApi.md#add_weight_log)                                                                                                               | **POST** /1/user/-/body/log/weight.json                                                                              | Log Weight                                              |
| _BodyApi_                                | [**delete_body_fat_log**](docs/BodyApi.md#delete_body_fat_log)                                                                                                     | **DELETE** /1/user/-/body/log/fat/{body-fat-log-id}.json                                                             | Delete Body Fat Log                                     |
| _BodyApi_                                | [**delete_weight_log**](docs/BodyApi.md#delete_weight_log)                                                                                                         | **DELETE** /1/user/-/body/log/weight/{body-weight-log-id}.json                                                       | Delete Weight Log                                       |
| _BodyApi_                                | [**get_body_fat_by_date**](docs/BodyApi.md#get_body_fat_by_date)                                                                                                   | **GET** /1/user/-/body/log/fat/date/{date}.json                                                                      | Get Body Fat Logs                                       |
| _BodyApi_                                | [**get_body_fat_by_date_period**](docs/BodyApi.md#get_body_fat_by_date_period)                                                                                     | **GET** /1/user/-/body/log/fat/date/{date}/{period}.json                                                             | Get Body Fat Logs                                       |
| _BodyApi_                                | [**get_body_fat_by_date_range**](docs/BodyApi.md#get_body_fat_by_date_range)                                                                                       | **GET** /1/user/-/body/log/fat/date/{base-date}/{end-date}.json                                                      | Get Body Fat Logs                                       |
| _BodyApi_                                | [**get_body_goals**](docs/BodyApi.md#get_body_goals)                                                                                                               | **GET** /1/user/-/body/log/{goal-type}/goal.json                                                                     | Get Body Goals                                          |
| _BodyApi_                                | [**get_weight_by_date**](docs/BodyApi.md#get_weight_by_date)                                                                                                       | **GET** /1/user/-/body/log/weight/date/{date}.json                                                                   | Get Weight Logs                                         |
| _BodyApi_                                | [**get_weight_by_date_period**](docs/BodyApi.md#get_weight_by_date_period)                                                                                         | **GET** /1/user/-/body/log/weight/date/{date}/{period}.json                                                          | Get Body Fat Logs                                       |
| _BodyApi_                                | [**get_weight_by_date_range**](docs/BodyApi.md#get_weight_by_date_range)                                                                                           | **GET** /1/user/-/body/log/weight/date/{base-date}/{end-date}.json                                                   | Get Body Fat Logs                                       |
| _BodyApi_                                | [**update_body_fat_goal**](docs/BodyApi.md#update_body_fat_goal)                                                                                                   | **POST** /1/user/-/body/log/fat/goal.json                                                                            | Update Body Fat Goal                                    |
| _BodyApi_                                | [**update_weight_goal**](docs/BodyApi.md#update_weight_goal)                                                                                                       | **POST** /1/user/-/body/log/weight/goal.json                                                                         | Update Weight Goal                                      |
| _BodyTimeSeriesApi_                      | [**get_body_resource_by_date_period**](docs/BodyTimeSeriesApi.md#get_body_resource_by_date_period)                                                                 | **GET** /1/user/-/body/{resource-path}/date/{date}/{period}.json                                                     | Get Body Time Series                                    |
| _BodyTimeSeriesApi_                      | [**get_body_resource_by_date_range**](docs/BodyTimeSeriesApi.md#get_body_resource_by_date_range)                                                                   | **GET** /1/user/-/body/{resource-path}/date/{base-date}/{end-date}.json                                              | Get Body Time Series                                    |
| _BreathingRateApi_                       | [**get_breathing_rate_summary_by_date**](docs/BreathingRateApi.md#get_breathing_rate_summary_by_date)                                                              | **GET** /1/user/-/br/date/{date}.json                                                                                | Get Breathing Rate Summary by Date                      |
| _BreathingRateApi_                       | [**get_breathing_rate_summary_by_interval**](docs/BreathingRateApi.md#get_breathing_rate_summary_by_interval)                                                      | **GET** /1/user/-/br/date/{startDate}/{endDate}.json                                                                 | Get Breathing Rate Summary by Interval                  |
| _BreathingRateIntradayApi_               | [**get_breathing_rate_intraday_by_date**](docs/BreathingRateIntradayApi.md#get_breathing_rate_intraday_by_date)                                                    | **GET** /1/user/-/br/date/{date}/all.json                                                                            | Get Breathing Rate Intraday by Date                     |
| _BreathingRateIntradayApi_               | [**get_breathing_rate_intraday_by_interval**](docs/BreathingRateIntradayApi.md#get_breathing_rate_intraday_by_interval)                                            | **GET** /1/user/-/br/date/{startDate}/{endDate}/all.json                                                             | Get Breathing Rate Intraday by Interval                 |
| _CardioFitnessScoreVO2MaxApi_            | [**get_vo2_max_summary_by_date**](docs/CardioFitnessScoreVO2MaxApi.md#get_vo2_max_summary_by_date)                                                                 | **GET** /1/user/-/cardioscore/date/{date}.json                                                                       | Get VO2 Max Summary by Date                             |
| _CardioFitnessScoreVO2MaxApi_            | [**get_vo2_max_summary_by_interval**](docs/CardioFitnessScoreVO2MaxApi.md#get_vo2_max_summary_by_interval)                                                         | **GET** /1/user/-/cardioscore/date/{startDate}/{endDate}.json                                                        | Get VO2 Max Summary by Interval                         |
| _DevicesApi_                             | [**add_alarms**](docs/DevicesApi.md#add_alarms)                                                                                                                    | **POST** /1/user/-/devices/tracker/{tracker-id}/alarms.json                                                          | Add Alarm                                               |
| _DevicesApi_                             | [**delete_alarms**](docs/DevicesApi.md#delete_alarms)                                                                                                              | **DELETE** /1/user/-/devices/tracker/{tracker-id}/alarms/{alarm-id}.json                                             | Delete Alarm                                            |
| _DevicesApi_                             | [**get_alarms**](docs/DevicesApi.md#get_alarms)                                                                                                                    | **GET** /1/user/-/devices/tracker/{tracker-id}/alarms.json                                                           | Get Alarms                                              |
| _DevicesApi_                             | [**get_devices**](docs/DevicesApi.md#get_devices)                                                                                                                  | **GET** /1/user/-/devices.json                                                                                       | Get Devices                                             |
| _DevicesApi_                             | [**update_alarms**](docs/DevicesApi.md#update_alarms)                                                                                                              | **POST** /1/user/-/devices/tracker/{tracker-id}/alarms/{alarm-id}.json                                               | Update Alarm                                            |
| _ElectrocardiogramApi_                   | [**get_ecg_log_list**](docs/ElectrocardiogramApi.md#get_ecg_log_list)                                                                                              | **GET** /1/user/-/ecg/list.json                                                                                      | Get ECG Log List                                        |
| _FriendsApi_                             | [**get_friends**](docs/FriendsApi.md#get_friends)                                                                                                                  | **GET** /1.1/user/-/friends.json                                                                                     | Get Friends                                             |
| _FriendsApi_                             | [**get_friends_leaderboard**](docs/FriendsApi.md#get_friends_leaderboard)                                                                                          | **GET** /1.1/user/-/leaderboard/friends.json                                                                         | Get Friends Leaderboard                                 |
| _HeartRateIntradayTimeSeriesApi_         | [**get_heart_by_date_intraday**](docs/HeartRateIntradayTimeSeriesApi.md#get_heart_by_date_intraday)                                                                | **GET** /1/user/-/activities/heart/date/{date}/1d/{detail-level}.json                                                | Get Heart Rate Intraday Time Series                     |
| _HeartRateIntradayTimeSeriesApi_         | [**get_heart_by_date_range_intraday**](docs/HeartRateIntradayTimeSeriesApi.md#get_heart_by_date_range_intraday)                                                    | **GET** /1/user/-/activities/heart/date/{date}/{end-date}/{detail-level}.json                                        | Get Heart Rate Intraday Time Series                     |
| _HeartRateIntradayTimeSeriesApi_         | [**get_heart_by_date_range_timestamp_intraday**](docs/HeartRateIntradayTimeSeriesApi.md#get_heart_by_date_range_timestamp_intraday)                                | **GET** /1/user/-/activities/heart/date/{date}/{end-date}/{detail-level}/time/{start-time}/{end-time}.json           | Get Heart Rate Intraday Time Series                     |
| _HeartRateIntradayTimeSeriesApi_         | [**get_heart_by_date_timestamp_intraday**](docs/HeartRateIntradayTimeSeriesApi.md#get_heart_by_date_timestamp_intraday)                                            | **GET** /1/user/-/activities/heart/date/{date}/1d/{detail-level}/time/{start-time}/{end-time}.json                   | Get Heart Rate Intraday Time Series                     |
| _HeartRateTimeSeriesApi_                 | [**get_heart_by_date_period**](docs/HeartRateTimeSeriesApi.md#get_heart_by_date_period)                                                                            | **GET** /1/user/-/activities/heart/date/{date}/{period}.json                                                         | Get Heart Rate Time Series                              |
| _HeartRateTimeSeriesApi_                 | [**get_heart_by_date_range**](docs/HeartRateTimeSeriesApi.md#get_heart_by_date_range)                                                                              | **GET** /1/user/-/activities/heart/date/{base-date}/{end-date}.json                                                  | Get Heart Rate Time Series                              |
| _HeartRateVariabilityApi_                | [**get_hrv_summary_date**](docs/HeartRateVariabilityApi.md#get_hrv_summary_date)                                                                                   | **GET** /1/user/-/hrv/date/{date}.json                                                                               | Get HRV Summary by Date                                 |
| _HeartRateVariabilityApi_                | [**get_hrv_summary_interval**](docs/HeartRateVariabilityApi.md#get_hrv_summary_interval)                                                                           | **GET** /1/user/-/hrv/date/{startDate}/{endDate}.json                                                                | Get HRV Summary by Interval                             |
| _HeartRateVariabilityIntradayApi_        | [**get_hrv_intraday_by_date**](docs/HeartRateVariabilityIntradayApi.md#get_hrv_intraday_by_date)                                                                   | **GET** /1/user/-/hrv/date/{date}/all.json                                                                           | Get HRV Intraday by Date                                |
| _HeartRateVariabilityIntradayApi_        | [**get_hrv_intraday_by_interval**](docs/HeartRateVariabilityIntradayApi.md#get_hrv_intraday_by_interval)                                                           | **GET** /1/user/-/hrv/date/{startDate}/{endDate}/all.json                                                            | Get HRV Intraday by Interval                            |
| _NutritionApi_                           | [**add_favorite_food**](docs/NutritionApi.md#add_favorite_food)                                                                                                    | **POST** /1/user/-/foods/log/favorite/{food-id}.json                                                                 | Add Favorite Food                                       |
| _NutritionApi_                           | [**add_foods**](docs/NutritionApi.md#add_foods)                                                                                                                    | **POST** /1/user/-/foods.json                                                                                        | Create Food                                             |
| _NutritionApi_                           | [**add_foods_log**](docs/NutritionApi.md#add_foods_log)                                                                                                            | **POST** /1/user/-/foods/log.json                                                                                    | Log Food                                                |
| _NutritionApi_                           | [**add_meal**](docs/NutritionApi.md#add_meal)                                                                                                                      | **POST** /1/user/-/meals.json                                                                                        | Create Meal                                             |
| _NutritionApi_                           | [**add_update_foods_goal**](docs/NutritionApi.md#add_update_foods_goal)                                                                                            | **POST** /1/user/-/foods/log/goal.json                                                                               | Update Food Goal                                        |
| _NutritionApi_                           | [**add_update_water_goal**](docs/NutritionApi.md#add_update_water_goal)                                                                                            | **POST** /1/user/-/foods/log/water/goal.json                                                                         | Update Water Goal                                       |
| _NutritionApi_                           | [**add_water_log**](docs/NutritionApi.md#add_water_log)                                                                                                            | **POST** /1/user/-/foods/log/water.json                                                                              | Log Water                                               |
| _NutritionApi_                           | [**delete_favorite_food**](docs/NutritionApi.md#delete_favorite_food)                                                                                              | **DELETE** /1/user/-/foods/log/favorite/{food-id}.json                                                               | Delete Favorite Food                                    |
| _NutritionApi_                           | [**delete_foods**](docs/NutritionApi.md#delete_foods)                                                                                                              | **DELETE** /1/user/-/foods/{food-id}.json                                                                            | Delete Custom Food                                      |
| _NutritionApi_                           | [**delete_foods_log**](docs/NutritionApi.md#delete_foods_log)                                                                                                      | **DELETE** /1/user/-/foods/log/{food-log-id}.json                                                                    | Delete Food Log                                         |
| _NutritionApi_                           | [**delete_meal**](docs/NutritionApi.md#delete_meal)                                                                                                                | **DELETE** /1/user/-/meals/{meal-id}.json                                                                            | Delete Meal                                             |
| _NutritionApi_                           | [**delete_water_log**](docs/NutritionApi.md#delete_water_log)                                                                                                      | **DELETE** /1/user/-/foods/log/water/{water-log-id}.json                                                             | Delete Water Log                                        |
| _NutritionApi_                           | [**edit_foods_log**](docs/NutritionApi.md#edit_foods_log)                                                                                                          | **POST** /1/user/-/foods/log/{food-log-id}.json                                                                      | Edit Food Log                                           |
| _NutritionApi_                           | [**get_favorite_foods**](docs/NutritionApi.md#get_favorite_foods)                                                                                                  | **GET** /1/user/-/foods/log/favorite.json                                                                            | Get Favorite Foods                                      |
| _NutritionApi_                           | [**get_foods_by_date**](docs/NutritionApi.md#get_foods_by_date)                                                                                                    | **GET** /1/user/-/foods/log/date/{date}.json                                                                         | Get Food Logs                                           |
| _NutritionApi_                           | [**get_foods_goal**](docs/NutritionApi.md#get_foods_goal)                                                                                                          | **GET** /1/user/-/foods/log/goal.json                                                                                | Get Food Goals                                          |
| _NutritionApi_                           | [**get_foods_info**](docs/NutritionApi.md#get_foods_info)                                                                                                          | **GET** /1/foods/{food-id}.json                                                                                      | Get Food                                                |
| _NutritionApi_                           | [**get_foods_list**](docs/NutritionApi.md#get_foods_list)                                                                                                          | **GET** /1/foods/search.json                                                                                         | Search Foods                                            |
| _NutritionApi_                           | [**get_foods_locales**](docs/NutritionApi.md#get_foods_locales)                                                                                                    | **GET** /1/foods/locales.json                                                                                        | Get Food Locales                                        |
| _NutritionApi_                           | [**get_foods_units**](docs/NutritionApi.md#get_foods_units)                                                                                                        | **GET** /1/foods/units.json                                                                                          | Get Food Units                                          |
| _NutritionApi_                           | [**get_frequent_foods**](docs/NutritionApi.md#get_frequent_foods)                                                                                                  | **GET** /1/user/-/foods/log/frequent.json                                                                            | Get Frequent Foods                                      |
| _NutritionApi_                           | [**get_meals**](docs/NutritionApi.md#get_meals)                                                                                                                    | **GET** /1/user/-/meals.json                                                                                         | Get Meals                                               |
| _NutritionApi_                           | [**get_recent_foods**](docs/NutritionApi.md#get_recent_foods)                                                                                                      | **GET** /1/user/-/foods/log/recent.json                                                                              | Get Recent Foods                                        |
| _NutritionApi_                           | [**get_water_by_date**](docs/NutritionApi.md#get_water_by_date)                                                                                                    | **GET** /1/user/-/foods/log/water/date/{date}.json                                                                   | Get Water Logs                                          |
| _NutritionApi_                           | [**get_water_goal**](docs/NutritionApi.md#get_water_goal)                                                                                                          | **GET** /1/user/-/foods/log/water/goal.json                                                                          | Get Water Goal                                          |
| _NutritionApi_                           | [**update_meal**](docs/NutritionApi.md#update_meal)                                                                                                                | **POST** /1/user/-/meals/{meal-id}.json                                                                              | Update Meal                                             |
| _NutritionApi_                           | [**update_water_log**](docs/NutritionApi.md#update_water_log)                                                                                                      | **POST** /1/user/-/foods/log/water/{water-log-id}.json                                                               | Update Water Log                                        |
| _NutritionTimeSeriesApi_                 | [**get_foods_by_date_range**](docs/NutritionTimeSeriesApi.md#get_foods_by_date_range)                                                                              | **GET** /1/user/-/foods/log/{resource-path}/date/{base-date}/{end-date}.json                                         | Get Food or Water Time Series                           |
| _NutritionTimeSeriesApi_                 | [**get_foods_resource_by_date_period**](docs/NutritionTimeSeriesApi.md#get_foods_resource_by_date_period)                                                          | **GET** /1/user/-/foods/log/{resource-path}/date/{date}/{period}.json                                                | Get Food or Water Time Series                           |
| _SleepApi_                               | [**add_sleep**](docs/SleepApi.md#add_sleep)                                                                                                                        | **POST** /1.2/user/-/sleep.json                                                                                      | Log Sleep                                               |
| _SleepApi_                               | [**delete_sleep**](docs/SleepApi.md#delete_sleep)                                                                                                                  | **DELETE** /1.2/user/-/sleep/{log-id}.json                                                                           | Delete Sleep Log                                        |
| _SleepApi_                               | [**get_sleep_by_date**](docs/SleepApi.md#get_sleep_by_date)                                                                                                        | **GET** /1.2/user/-/sleep/date/{date}.json                                                                           | Get Sleep Log                                           |
| _SleepApi_                               | [**get_sleep_by_date_range**](docs/SleepApi.md#get_sleep_by_date_range)                                                                                            | **GET** /1.2/user/-/sleep/date/{base-date}/{end-date}.json                                                           | Get Sleep Logs by Date Range                            |
| _SleepApi_                               | [**get_sleep_goal**](docs/SleepApi.md#get_sleep_goal)                                                                                                              | **GET** /1.2/user/-/sleep/goal.json                                                                                  | Get Sleep Goal                                          |
| _SleepApi_                               | [**get_sleep_list**](docs/SleepApi.md#get_sleep_list)                                                                                                              | **GET** /1.2/user/-/sleep/list.json                                                                                  | Get Sleep Logs List                                     |
| _SleepApi_                               | [**update_sleep_goal**](docs/SleepApi.md#update_sleep_goal)                                                                                                        | **POST** /1.2/user/-/sleep/goal.json                                                                                 | Update Sleep Goal                                       |
| _SpO2Api_                                | [**get_sp_o2_summary_by_date**](docs/SpO2Api.md#get_sp_o2_summary_by_date)                                                                                         | **GET** /1/user/-/spo2/date/{date}.json                                                                              | Get SpO2 Summary by Date                                |
| _SpO2Api_                                | [**get_sp_o2_summary_by_interval**](docs/SpO2Api.md#get_sp_o2_summary_by_interval)                                                                                 | **GET** /1/user/-/spo2/date/{startDate}/{endDate}.json                                                               | Get SpO2 Summary by Interval                            |
| _SpO2IntradayApi_                        | [**get_sp_o2_intraday_by_date**](docs/SpO2IntradayApi.md#get_sp_o2_intraday_by_date)                                                                               | **GET** /1/user/-/spo2/date/{date}/all.json                                                                          | Get SpO2 Intraday by Date                               |
| _SpO2IntradayApi_                        | [**get_sp_o2_intraday_by_interval**](docs/SpO2IntradayApi.md#get_sp_o2_intraday_by_interval)                                                                       | **GET** /1/user/-/spo2/date/{startDate}/{endDate}/all.json                                                           | Get SpO2 Intraday by Interval                           |
| _SubscriptionsApi_                       | [**add_subscriptions**](docs/SubscriptionsApi.md#add_subscriptions)                                                                                                | **POST** /1/user/-/{collection-path}/apiSubscriptions/{subscription-id}.json                                         | Add a Subscription                                      |
| _SubscriptionsApi_                       | [**delete_subscriptions**](docs/SubscriptionsApi.md#delete_subscriptions)                                                                                          | **DELETE** /1/user/-/{collection-path}/apiSubscriptions/{subscription-id}.json                                       | Delete a Subscription                                   |
| _SubscriptionsApi_                       | [**get_subscriptions_list**](docs/SubscriptionsApi.md#get_subscriptions_list)                                                                                      | **GET** /1/user/-/{collection-path}/apiSubscriptions.json                                                            | Get a List of Subscriptions                             |
| _TemperatureApi_                         | [**get_temp_core_summary_by_date**](docs/TemperatureApi.md#get_temp_core_summary_by_date)                                                                          | **GET** /1/user/-/temp/core/date/{date}.json                                                                         | Get Temperature (Core) Summary by Date                  |
| _TemperatureApi_                         | [**get_temp_core_summary_by_interval**](docs/TemperatureApi.md#get_temp_core_summary_by_interval)                                                                  | **GET** /1/user/-/temp/core/date/{startDate}/{endDate}.json                                                          | Get Temperature (Core) Summary by Interval              |
| _TemperatureApi_                         | [**get_temp_skin_summary_by_interval**](docs/TemperatureApi.md#get_temp_skin_summary_by_interval)                                                                  | **GET** /1/user/-/temp/skin/date/{startDate}/{endDate}.json                                                          | Get Temperature (Skin) Summary by Interval              |
| _TemperatureApi_                         | [**get_temp_skin_summary_date**](docs/TemperatureApi.md#get_temp_skin_summary_date)                                                                                | **GET** /1/user/-/temp/skin/date/{date}.json                                                                         | Get Temperature (Skin) Summary by Date                  |
| _UserApi_                                | [**get_badges**](docs/UserApi.md#get_badges)                                                                                                                       | **GET** /1/user/-/badges.json                                                                                        | Get Badges                                              |
| _UserApi_                                | [**get_profile**](docs/UserApi.md#get_profile)                                                                                                                     | **GET** /1/user/-/profile.json                                                                                       | Get Profile                                             |
| _UserApi_                                | [**update_profile**](docs/UserApi.md#update_profile)                                                                                                               | **POST** /1/user/-/profile.json                                                                                      | Update Profile                                          |

## Documentation For Models

- [FoodItem](docs/FoodItem.md)
- [Meal](docs/Meal.md)
- [Oauth2IntrospectBody](docs/Oauth2IntrospectBody.md)
- [Oauth2RevokeBody](docs/Oauth2RevokeBody.md)
- [ProfileJsonBody](docs/ProfileJsonBody.md)

## Documentation For Authorization

## oauth2

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://www.fitbit.com/oauth2/authorize
- **Scopes**:
- **activity**: Activity data and exercise log related features, such as steps, distance, calories burned, and active minutes
- **cardio_fitness**: Maximum or optimum rate at which the user’s heart, lungs, and muscles can effectively use oxygen during exercise
- **electrocardiogram**: A users on-device ECG readings
- **heartrate**: Continuous heart rate &amp; HRV data and related analysis
- **location**: GPS and other location data
- **nutrition**: Calorie consumption and nutrition related features, such as food/water logging, goals, and plans
- **oxygen_saturation**: SpO2 (Oxygen Saturation) is a measurement of your blood oxygen level
- **profile**: Basic user information
- **respiratory_rate**: Respiratory Rate is a measurement of your breaths at night.
- **settings**: User account and device settings, such as alarms
- **sleep**: Sleep logs and related sleep analysis
- **social**: Friend-related features, such as friend list and leaderboard
- **temperature**: Core and skin temperature data
- **weight**: Weight and related information, such as body mass index, body fat percentage, and goals

## Author
